[X2Go-Commits] [python-x2go] 01/04: sphinx hyperrefs: Fix all remaining hyperrefs that are still in epydoc format.

git-admin at x2go.org git-admin at x2go.org
Thu Sep 6 17:54:55 CEST 2018


This is an automated email from the git hooks/post-receive script.

x2go pushed a commit to branch master
in repository python-x2go.

commit a5b26e8fca8611447cef2467635c8ba98ed18e14
Author: Mike Gabriel <mike.gabriel at das-netzwerkteam.de>
Date:   Thu Sep 6 16:02:21 2018 +0200

    sphinx hyperrefs: Fix all remaining hyperrefs that are still in epydoc format.
---
 x2go/__init__.py                     |  4 +--
 x2go/_paramiko.py                    |  8 +++---
 x2go/backends/control/plain.py       | 12 ++++----
 x2go/backends/info/plain.py          |  2 +-
 x2go/backends/printing/file.py       | 10 +++----
 x2go/backends/printing/winreg.py     |  2 +-
 x2go/backends/profiles/base.py       |  8 +++---
 x2go/backends/profiles/httpbroker.py |  2 +-
 x2go/backends/proxy/base.py          |  8 +++---
 x2go/backends/settings/file.py       |  2 +-
 x2go/backends/settings/winreg.py     |  2 +-
 x2go/checkhosts.py                   | 18 ++++++------
 x2go/cleanup.py                      |  2 +-
 x2go/client.py                       | 56 ++++++++++++++++++------------------
 x2go/forward.py                      |  2 +-
 x2go/inifiles.py                     |  4 +--
 x2go/mimebox.py                      |  2 +-
 x2go/printqueue.py                   |  2 +-
 x2go/pulseaudio.py                   |  2 +-
 x2go/registry.py                     |  6 ++--
 x2go/rforward.py                     | 28 +++++++++---------
 x2go/session.py                      | 18 ++++++------
 x2go/sftpserver.py                   | 18 ++++++------
 x2go/utils.py                        |  4 +--
 x2go/xserver.py                      |  4 +--
 25 files changed, 113 insertions(+), 113 deletions(-)

diff --git a/x2go/__init__.py b/x2go/__init__.py
index 77d6c1b..89d10f9 100644
--- a/x2go/__init__.py
+++ b/x2go/__init__.py
@@ -91,7 +91,7 @@ API Structure
 
     However, it might be handy to retrieve a whole X2Go session instance
     from the :class:`x2go.client.X2GoClient` instance. This can be achieved by the
-    L{X2GoClient.register_session()} method::
+    :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` method::
 
         import x2go
         my_x2gocli = MyX2GoClient()
@@ -105,7 +105,7 @@ API Structure
     session manually (i.e. a session that is based on a pre-configured session profile
     in either of the »sessions« config files).
 
-    The L{X2GoClient.register_session()} method---in object-retrieval-mode---returns
+    The :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` method---in object-retrieval-mode---returns
     an :class:`x2go.session.X2GoSession` instance. With this instance you can then manage
     your X2Go session::
 
diff --git a/x2go/_paramiko.py b/x2go/_paramiko.py
index c600198..0fec247 100644
--- a/x2go/_paramiko.py
+++ b/x2go/_paramiko.py
@@ -54,8 +54,8 @@ def _SSHClient_save_host_keys(self, filename):
 
     Save the host keys back to a file.
     Only the host keys loaded with
-    L{load_host_keys} (plus any added directly) will be saved -- not any
-    host keys loaded with L{load_system_host_keys}.
+    :func:`load_host_keys()` (plus any added directly) will be saved -- not any
+    host keys loaded with :func:`load_system_host_keys()`.
 
     :param filename: the filename to save to
     :type filename: str
@@ -88,7 +88,7 @@ def _HostKeys_load(self, filename):
     ``os.path.expanduser("~/.ssh/known_hosts")``.
 
     If this method is called multiple times, the host keys are merged,
-    not cleared. So multiple calls to ``load`` will just call L{add},
+    not cleared. So multiple calls to ``load`` will just call :func:`add()`,
     replacing any existing entries and adding new ones.
 
     :param filename: name of the file to read host keys from
@@ -122,7 +122,7 @@ def _HostKeys_add(self, hostname, keytype, key, hash_hostname=True):
     :param keytype: key type (``"ssh-rsa"``, ``"ssh-dss"`` or ``"ecdsa-sha2-nistp256"``)
     :type keytype: str
     :param key: the key to add
-    :type key: L{PKey}
+    :type key: :class:`PKey`
     :param hash_hostname: hash the system's hostname (Default value = True)
     :type hash_hostname: ``bool``
 
diff --git a/x2go/backends/info/plain.py b/x2go/backends/info/plain.py
index ac9890d..17bd45b 100644
--- a/x2go/backends/info/plain.py
+++ b/x2go/backends/info/plain.py
@@ -324,7 +324,7 @@ class X2GoServerSessionInfo(object):
 
     def __init__(self):
         """\
-        Class constructor, identical to L{clear()} method.
+        Class constructor, identical to :func:`clear()` method.
 
         """
         self.clear()
diff --git a/x2go/backends/printing/file.py b/x2go/backends/printing/file.py
index ca6cec3..0cef1c5 100644
--- a/x2go/backends/printing/file.py
+++ b/x2go/backends/printing/file.py
@@ -87,7 +87,7 @@ class X2GoClientPrinting(inifiles.X2GoIniFile):
             directory filename)
         @type config_files: ``list``
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override
-            Python X2Go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in :module:`x2go.defaults`
         @type defaults: ``dict``
         @param logger: you can pass an :class:`x2go.logger.X2GoLogger` object to the
             :class:`x2go.printactions.X2GoPrintAction` constructor
@@ -138,7 +138,7 @@ class X2GoClientPrinting(inifiles.X2GoIniFile):
         """\
         Return the print action described by the »printing« configuration file.
 
-        This method has property status and wraps around the L{get_print_action}
+        This method has property status and wraps around the :func:`get_print_action()`
 
 
         :returns: Returns the print action object
@@ -175,7 +175,7 @@ class X2GoClientPrinting(inifiles.X2GoIniFile):
 
     def get_property(self, print_property):
         """\
-        Retrieve a printing property as mapped by the L{_print_property_map} dictionary.
+        Retrieve a printing property as mapped by the :func:`_print_property_map()` dictionary.
 
         :param print_property: a printing property
         :type print_property: ``str``
@@ -193,7 +193,7 @@ class X2GoClientPrinting(inifiles.X2GoIniFile):
 
     def set_property(self, print_property, value):
         """\
-        Set a printing property as mapped by the L{_print_property_map} dictionary.
+        Set a printing property as mapped by the :func:`_print_property_map()` dictionary.
 
         :param print_property: a printing property
         :type print_property: ``str``
@@ -218,7 +218,7 @@ class X2GoClientPrinting(inifiles.X2GoIniFile):
         """\
         Accept a new print action configuration. This includes the print action
         itself (DIALOG, PDFVIEW, PDFSAVE, PRINT or PRINTCMD) and related printing properties
-        as mapped by the L{_print_property_map} dictionary.
+        as mapped by the :func:`_print_property_map()` dictionary.
 
         :param print_action: the print action name
         :type print_action: ``str``
diff --git a/x2go/backends/printing/winreg.py b/x2go/backends/printing/winreg.py
index 67a4f44..c2a037e 100644
--- a/x2go/backends/printing/winreg.py
+++ b/x2go/backends/printing/winreg.py
@@ -64,7 +64,7 @@ class X2GoClientPrinting(object):
     def __init__(self, defaults=None, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override
-            Python X2Go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in :module:`x2go.defaults`
         @type defaults: ``dict``
         @param logger: you can pass an :class:`x2go.logger.X2GoLogger` object to the
             :class:`x2go.printactions.X2GoPrintAction` constructor
diff --git a/x2go/backends/profiles/base.py b/x2go/backends/profiles/base.py
index 0cdb142..d3e3d06 100644
--- a/x2go/backends/profiles/base.py
+++ b/x2go/backends/profiles/base.py
@@ -216,7 +216,7 @@ class X2GoSessionProfiles(object):
         :param profile_id_or_name: profile name or profile ID (Default value = None)
         :type profile_id_or_name: ``str``
         :param profile_id: if the profile ID is known, pass it in directly and skip
-            the L{check_profile_id_or_name()} call (Default value = None)
+            the :func:`check_profile_id_or_name()` call (Default value = None)
         :type profile_id: ``str``
         :returns: ``True`` if the session profile of the specified name/ID is mutable
         :rtype: ``bool``
@@ -439,7 +439,7 @@ class X2GoSessionProfiles(object):
 
     def has_profile_id(self, profile_id):
         """\
-        Does a session profile of a given profile ID exist? (Faster than L{has_profile()}.)
+        Does a session profile of a given profile ID exist? (Faster than :func:`has_profile()`.)
 
         :param profile_id: profile ID
         :type profile_id: ``str``
@@ -462,7 +462,7 @@ class X2GoSessionProfiles(object):
 
     def has_profile_name(self, profile_name):
         """\
-        Does a session profile of a given profile name exist? (Faster than L{has_profile()}.)
+        Does a session profile of a given profile name exist? (Faster than :func:`has_profile()`.)
 
         :param profile_name: profile name
         :type profile_name: ``str``
@@ -582,7 +582,7 @@ class X2GoSessionProfiles(object):
         :param value: the value to update the session profile option with
         :type value: any type, depends on the session profile option
         :param profile_id: if the profile ID is known, pass it in directly and skip
-            the L{check_profile_id_or_name()} call (Default value = None)
+            the :func:`check_profile_id_or_name()` call (Default value = None)
         :type profile_id: ``str``
 
         """
diff --git a/x2go/backends/profiles/httpbroker.py b/x2go/backends/profiles/httpbroker.py
index 17fb045..a13ddbd 100644
--- a/x2go/backends/profiles/httpbroker.py
+++ b/x2go/backends/profiles/httpbroker.py
@@ -323,7 +323,7 @@ class X2GoSessionProfiles(base.X2GoSessionProfiles):
     def broker_selectsession(self, profile_id):
         """\
         Select a session from the list of available session profiles (presented by
-        L{broker_listprofiles}). This method requests a session information dictionary
+        :func:`broker_listprofiles()`). This method requests a session information dictionary
         (server, port, SSH keys, already running / suspended sessions, etc.) from the
         session broker for the provided ``profile_id``.
 
diff --git a/x2go/backends/proxy/base.py b/x2go/backends/proxy/base.py
index 2db38f9..5c2c745 100644
--- a/x2go/backends/proxy/base.py
+++ b/x2go/backends/proxy/base.py
@@ -88,12 +88,12 @@ class X2GoProxy(threading.Thread):
         @type session_log: ``str``
         @param sessions_rootdir: base dir where X2Go session files are stored (by default: ~/.x2go)
         @type sessions_rootdir: ``str``
-        @param proxy_options: a set of very L{base.X2GoProxy} backend specific options; any option that is not known
-            to the L{base.X2GoProxy} backend will simply be ignored
+        @param proxy_options: a set of very :class:`X2GoProxy <x2go.backends.proxy.base.X2GoProxy>` backend specific options; any option that is not known
+            to the :class:`x2go.backends.proxy.base.X2GoProxy` backend will simply be ignored
         @type proxy_options: ``dict``
         @param logger: you can pass an :class:`x2go.logger.X2GoLogger` object to the
-            L{base.X2GoProxy} constructor
-        @param session_instance: the :class:`x2go.session.X2GoSession` instance this L{base.X2GoProxy} instance belongs to
+            :class:`x2go.backends.proxy.base.X2GoProxy` constructor
+        @param session_instance: the :class:`x2go.session.X2GoSession` instance this :class:`x2go.backends.proxy.base.X2GoProxy` instance belongs to
         @type session_instance: :class:`x2go.session.X2GoSession` instance
         @type logger: :class:`x2go.logger.X2GoLogger` instance
         @param loglevel: if no :class:`x2go.logger.X2GoLogger` object has been supplied a new one will be
diff --git a/x2go/backends/settings/file.py b/x2go/backends/settings/file.py
index 6709b6a..c0d9a1a 100644
--- a/x2go/backends/settings/file.py
+++ b/x2go/backends/settings/file.py
@@ -49,7 +49,7 @@ class X2GoClientSettings(inifiles.X2GoIniFile):
     def __init__(self, config_files=_X2GO_SETTINGS_CONFIGFILES, defaults=_X2GO_CLIENTSETTINGS_DEFAULTS, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         Constructs an :class:`x2go.backends.settings.base.X2GoClientSettings` instance. This is normally done from within an :class:`x2go.client.X2GoClient` instance.
-        You can retrieve this :class:`x2go.backends.settings.base.X2GoClientSettings` instance with the L{X2GoClient.get_client_settings()}
+        You can retrieve this :class:`x2go.backends.settings.base.X2GoClientSettings` instance with the :func:`X2GoClient.get_client_settings() <x2go.client.X2GoClient.get_client_settings()>`
         method.
 
         On construction the :class:`x2go.backends.settings.base.X2GoClientSettings` object is filled with values from the configuration files::
diff --git a/x2go/backends/settings/winreg.py b/x2go/backends/settings/winreg.py
index 6ff079b..df7c57e 100644
--- a/x2go/backends/settings/winreg.py
+++ b/x2go/backends/settings/winreg.py
@@ -56,7 +56,7 @@ class X2GoClientSettings(inifiles.X2GoIniFile):
     def __init__(self, defaults=_X2GO_CLIENTSETTINGS_DEFAULTS, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         Constructs an :class:`x2go.backends.settings.base.X2GoClientSettings` instance. This is normally done from within an :class:`x2go.client.X2GoClient` instance.
-        You can retrieve this :class:`x2go.backends.settings.base.X2GoClientSettings` instance with the L{X2GoClient.get_client_settings()}
+        You can retrieve this :class:`x2go.backends.settings.base.X2GoClientSettings` instance with the :func:`X2GoClient.get_client_settings() <x2go.client.X2GoClient.get_client_settings()>`
         method.
 
         On construction the :class:`x2go.backends.settings.base.X2GoClientSettings` object is filled with values from the Windows registry::
diff --git a/x2go/checkhosts.py b/x2go/checkhosts.py
index 50765b4..3e125e4 100644
--- a/x2go/checkhosts.py
+++ b/x2go/checkhosts.py
@@ -194,13 +194,13 @@ class X2GoInteractiveAddPolicy(X2GoMissingHostKeyPolicy):
     Paramiko/SSH connect has been attempted. This class needs information
     about the associated :class:`x2go.session.X2GoSession` instance.
 
-    Once called, the L{missing_host_key} method of this class will try to call
-    L{X2GoSession.HOOK_check_host_dialog()}. This hook method---if not re-defined
-    in your application---will then try to call the L{X2GoClient.HOOK_check_host_dialog()},
+    Once called, the :func:`missing_host_key()` method of this class will try to call
+    :func:`X2GoSession.HOOK_check_host_dialog() <x2go.session.X2GoSession.HOOK_check_host_dialog()>`. This hook method---if not re-defined
+    in your application---will then try to call the :func:`X2GoClient.HOOK_check_host_dialog() <x2go.client.X2GoClient.HOOK_check_host_dialog()>`,
     which then will return ``True`` by default if not customized in your application.
 
     To accept host key checks, make sure to either customize the
-    L{X2GoClient.HOOK_check_host_dialog()} method or the L{X2GoSession.HOOK_check_host_dialog()}
+    :func:`X2GoClient.HOOK_check_host_dialog() <x2go.client.X2GoClient.HOOK_check_host_dialog()>` method or the :func:`X2GoSession.HOOK_check_host_dialog() <x2go.session.X2GoSession.HOOK_check_host_dialog()>`
     method and hook some interactive user dialog to either of them.
 
 
@@ -209,13 +209,13 @@ class X2GoInteractiveAddPolicy(X2GoMissingHostKeyPolicy):
         """\
         Handle a missing host key situation. This method calls
 
-        Once called, the L{missing_host_key} method will try to call
-        L{X2GoSession.HOOK_check_host_dialog()}. This hook method---if not re-defined
-        in your application---will then try to call the L{X2GoClient.HOOK_check_host_dialog()},
+        Once called, the :func:`missing_host_key()` method will try to call
+        :func:`X2GoSession.HOOK_check_host_dialog() <x2go.session.X2GoSession.HOOK_check_host_dialog()>`. This hook method---if not re-defined
+        in your application---will then try to call the :func:`X2GoClient.HOOK_check_host_dialog() <x2go.client.X2GoClient.HOOK_check_host_dialog()>`,
         which then will return ``True`` by default if not customized in your application.
 
         To accept host key checks, make sure to either customize the
-        L{X2GoClient.HOOK_check_host_dialog()} method or the L{X2GoSession.HOOK_check_host_dialog()}
+        :func:`X2GoClient.HOOK_check_host_dialog() <x2go.client.X2GoClient.HOOK_check_host_dialog()>` method or the :func:`X2GoSession.HOOK_check_host_dialog() <x2go.session.X2GoSession.HOOK_check_host_dialog()>`
         method and hook some interactive user dialog to either of them.
 
         :param client: SSH client (``X2GoControlSession*``) instance
@@ -290,7 +290,7 @@ def check_ssh_host_key(x2go_sshclient_instance, hostname, port=22):
     :type port: ``int``
     :returns: returns a tuple with the following components (<host_ok>, <hostname>, <port>, <fingerprint>, <fingerprint_type>)
     :rtype: ``tuple``
-    :raises SSHException: if an SSH exception occurred, that we did not provocate in L{X2GoInteractiveAddPolicy.missing_host_key()}
+    :raises SSHException: if an SSH exception occurred, that we did not provocate in :func:`X2GoInteractiveAddPolicy.missing_host_key() <x2go.checkhosts.X2GoInteractiveAddPolicy.missing_host_key()`
 
     """
     _hostname = hostname
diff --git a/x2go/cleanup.py b/x2go/cleanup.py
index 6fb51d2..880f13a 100644
--- a/x2go/cleanup.py
+++ b/x2go/cleanup.py
@@ -56,7 +56,7 @@ def x2go_cleanup(e=None, threads=None):
         except (KeyboardInterrupt, SystemExit):
             x2go.x2go_cleanup()
 
-    :param e: if L{x2go_cleanup} got called as you caught an exception in your code this can be the
+    :param e: if :func:`x2go_cleanup()` got called as you caught an exception in your code this can be the
         ``Exception`` that we will process at the end of the clean-up (or if clean-up failed or was not
         appropriate) (Default value = None)
     :type e: ``exception``
diff --git a/x2go/forward.py b/x2go/forward.py
index 2ad0f7e..0e2d5c2 100644
--- a/x2go/forward.py
+++ b/x2go/forward.py
@@ -281,7 +281,7 @@ def stop_forward_tunnel(fw_server):
     """\
     Tear down a given Paramiko/SSH port forwarding tunnel.
 
-    :param fw_server: an :class:`x2go.forward.X2GoFwServer` instance as returned by the L{start_forward_tunnel()} function
+    :param fw_server: an :class:`x2go.forward.X2GoFwServer` instance as returned by the :func:`start_forward_tunnel()` function
     :type fw_server: ``obj``
 
     """
diff --git a/x2go/inifiles.py b/x2go/inifiles.py
index d74700d..def313a 100644
--- a/x2go/inifiles.py
+++ b/x2go/inifiles.py
@@ -66,7 +66,7 @@ class X2GoIniFile(object):
             directory filename)
         @type config_files: ``list``
         @param defaults: a cascaded Python dicitionary structure with ini file defaults (to override
-            Python X2Go's hard coded defaults in L{defaults}
+            Python X2Go's hard coded defaults in :module:`x2go.defaults`
         @type defaults: ``dict``
         @param logger: you can pass an :class:`x2go.logger.X2GoLogger` object to the
             :class:`x2go.inifiles.X2GoIniFile` constructor
@@ -152,7 +152,7 @@ class X2GoIniFile(object):
         This methods affects a SafeConfigParser object held in
         RAM. No configuration file is affected by this
         method. To write the configuration to disk use
-        the L{write()} method.
+        the :func:`write()` method.
 
         :param section: the ini file section
         :type section: ``str``
diff --git a/x2go/mimebox.py b/x2go/mimebox.py
index 18f6b6f..3afc05c 100644
--- a/x2go/mimebox.py
+++ b/x2go/mimebox.py
@@ -271,7 +271,7 @@ class X2GoMIMEboxJob(threading.Thread):
     For each X2Go MIME box job we create a sub-thread that let's
     the MIME box job be processed in the background.
 
-    As a handler for this class the function L{x2go_mimeboxjob_handler()}
+    As a handler for this class the function :func:`x2go_mimeboxjob_handler()`
     is used.
 
 
diff --git a/x2go/printqueue.py b/x2go/printqueue.py
index a5771a3..f331c4a 100644
--- a/x2go/printqueue.py
+++ b/x2go/printqueue.py
@@ -289,7 +289,7 @@ class X2GoPrintJob(threading.Thread):
     For each X2Go print job we create a sub-thread that let's
     the print job be processed in the background.
 
-    As a handler for this class the function L{x2go_printjob_handler()}
+    As a handler for this class the function :func:`x2go_printjob_handler()`
     is used.
 
 
diff --git a/x2go/pulseaudio.py b/x2go/pulseaudio.py
index d405294..c6aaeac 100644
--- a/x2go/pulseaudio.py
+++ b/x2go/pulseaudio.py
@@ -92,7 +92,7 @@ class X2GoPulseAudio(threading.Thread):
     def run(self):
         """\
         This method is called once the ``X2GoPulseAudio.start()`` method has been called. To tear
-        down the Pulseaudio daemon call the L{X2GoPulseAudio.stop_thread()} method.
+        down the Pulseaudio daemon call the :func:`X2GoPulseAudio.stop_thread() <x2go.pulseaudio.X2GoPulseAudio.stop_thread()` method.
 
 
         """
diff --git a/x2go/registry.py b/x2go/registry.py
index 00ee797..e9fcc8b 100644
--- a/x2go/registry.py
+++ b/x2go/registry.py
@@ -243,7 +243,7 @@ class X2GoSessionRegistry(object):
         :param profile_id: alternatively, a profile ID can be given (the stati of all registered sessions for this session
             profile will be updated) (Default value = None)
         :type profile_id: ``str``
-        :param session_list: an optional ``X2GoServerSessionList*`` instance (as returned by the L{X2GoClient.list_sessions()} command can
+        :param session_list: an optional ``X2GoServerSessionList*`` instance (as returned by the :func:`X2GoClient.list_sessions() <x2go.client.X2GoClient.list_sessions()>` command can
             be passed to this method. (Default value = None)
         :type session_list: ``X2GoServerSessionList*`` instance
         :param force_update: make sure the session status gets really updated (Default value = False)
@@ -390,7 +390,7 @@ class X2GoSessionRegistry(object):
 
         :param profile_name: session profile name to register available X2Go sessions for
         :type profile_name: ``str``
-        :param session_list: an optional ``X2GoServerSessionList*`` instance (as returned by the L{X2GoClient.list_sessions()} command can
+        :param session_list: an optional ``X2GoServerSessionList*`` instance (as returned by the :func:`X2GoClient.list_sessions() <x2go.client.X2GoClient.list_sessions()>` command can
             be passed to this method. (Default value = None)
         :type session_list: ``X2GoServerSessionList*`` instance
         :param newly_connected: give a hint that the session profile got newly connected (Default value = False)
@@ -510,7 +510,7 @@ class X2GoSessionRegistry(object):
         :type sessions_rootdir: ``str``
         :param ssh_rootdir: ssh base dir (default: ~/.ssh)
         :type ssh_rootdir: ``str``
-        :param keep_controlsession_alive: On last L{X2GoSession.disconnect()} keep the associated ``X2GoControlSession`` instance alive?
+        :param keep_controlsession_alive: On last :func:`X2GoSession.disconnect() <x2go.session.X2GoSession.disconnect()>` keep the associated ``X2GoControlSession`` instance alive?
         :type keep_controlsession_alive: ``bool``
         :param add_to_known_hosts: Auto-accept server host validity?
         :type add_to_known_hosts: ``bool``
diff --git a/x2go/rforward.py b/x2go/rforward.py
index 3d118e4..37ce774 100644
--- a/x2go/rforward.py
+++ b/x2go/rforward.py
@@ -93,10 +93,10 @@ class X2GoRevFwTunnel(threading.Thread):
         """\
         Setup a reverse tunnel through Paramiko/SSH.
 
-        After the reverse tunnel has been setup up with L{X2GoRevFwTunnel.start()} it waits
-        for notification from L{X2GoRevFwTunnel.notify()} to accept incoming channels. This
-        notification (L{X2GoRevFwTunnel.notify()} gets called from within the transport's
-        TCP handler function L{x2go_transport_tcp_handler} of the :class:`x2go.session.X2GoSession` instance.
+        After the reverse tunnel has been setup up with :func:`X2GoRevFwTunnel.start() <x2go.rforward.X2GoRevFwTunnel.start()>` it waits
+        for notification from :func:`X2GoRevFwTunnel.notify() <x2go.rforward.X2GoRevFwTunnel.notify()>` to accept incoming channels. This
+        notification (:func:`X2GoRevFwTunnel.notify() <x2go.rforward.X2GoRevFwTunnel.notify()>` gets called from within the transport's
+        TCP handler function :func:`x2go_transport_tcp_handler()` of the :class:`x2go.session.X2GoSession` instance.
 
         @param server_port: the TCP/IP port on the X2Go server (starting point of the tunnel),
             normally some number above 30000
@@ -198,7 +198,7 @@ class X2GoRevFwTunnel(threading.Thread):
         TCP handler.
 
         The sent notification will trigger a ``thread.Condition()`` waiting for notification
-        in L{X2GoRevFwTunnel.run()}.
+        in :func:`X2GoRevFwTunnel.run() <x2go.rforward.X2GoRevFwTunnel.run()>`.
 
 
         """
@@ -237,22 +237,22 @@ class X2GoRevFwTunnel(threading.Thread):
     def run(self):
         """\
         This method gets run once an :class:`x2go.rforward.X2GoRevFwTunnel` has been started with its
-        L{start()} method. Use :class:`x2go.rforward.X2GoRevFwTunnel`.stop_thread() to stop the
+        :func:`start()` method. Use :class:`x2go.rforward.X2GoRevFwTunnel`.stop_thread() to stop the
         reverse forwarding tunnel again. You can also temporarily lock the tunnel
-        down with L{X2GoRevFwTunnel.pause()} and L{X2GoRevFwTunnel.resume()}).
+        down with :func:`X2GoRevFwTunnel.pause() <x2go.rforward.X2GoRevFwTunnel.pause()>` and :func:`X2GoRevFwTunnel.resume() <x2go.rforward.X2GoRevFwTunnel.resume()>`).
 
-        L{X2GoRevFwTunnel.run()} waits for notifications of an appropriate incoming
-        Paramiko/SSH channel (issued by L{X2GoRevFwTunnel.notify()}). Appropriate in
+        :func:`X2GoRevFwTunnel.run() <x2go.rforward.X2GoRevFwTunnel.run()>` waits for notifications of an appropriate incoming
+        Paramiko/SSH channel (issued by :func:`X2GoRevFwTunnel.notify() <x2go.rforward.X2GoRevFwTunnel.notify()>`). Appropriate in
         this context means, that its start point on the X2Go server matches the class's
         property ``server_port``.
 
-        Once a new incoming channel gets announced by the L{notify()} method, a new
+        Once a new incoming channel gets announced by the :func:`notify()` method, a new
         :class:`x2go.rforward.X2GoRevFwChannelThread` instance will be initialized. As a data stream handler,
-        the function L{x2go_rev_forward_channel_handler()} will be used.
+        the function :func:`x2go_rev_forward_channel_handler()` will be used.
 
         The channel will last till the connection gets dropped on the X2Go server side or
-        until the tunnel gets paused by an L{X2GoRevFwTunnel.pause()} call or stopped via the
-        L{X2GoRevFwTunnel.stop_thread()} method.
+        until the tunnel gets paused by an :func:`X2GoRevFwTunnel.pause() <x2go.rforward.X2GoRevFwTunnel.pause()>` call or stopped via the
+        :func:`X2GoRevFwTunnel.stop_thread() <x2go.rforward.X2GoRevFwTunnel.stop_thread()>` method.
 
 
         """
@@ -298,7 +298,7 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
         - ... if the connecting application closes the connection and thus, drops
           the channel, or
         - ... if the :class:`x2go.rforward.X2GoRevFwTunnel` parent thread gets paused. The call
-          of L{X2GoRevFwTunnel.pause()} on the instance can be used to shut down all incoming
+          of :func:`X2GoRevFwTunnel.pause() <x2go.rforward.X2GoRevFwTunnel.pause()>` on the instance can be used to shut down all incoming
           tunneled SSH connections associated to this :class:`x2go.rforward.X2GoRevFwTunnel` instance
           from within a Python X2Go application.
 
diff --git a/x2go/session.py b/x2go/session.py
index bfc206f..b174c38 100644
--- a/x2go/session.py
+++ b/x2go/session.py
@@ -219,7 +219,7 @@ class X2GoSession(object):
         @type sessions_rootdir: ``str``
         @param ssh_rootdir: ssh base dir (default: ~/.ssh)
         @type ssh_rootdir: ``str``
-        @param keep_controlsession_alive: On last L{X2GoSession.disconnect()} keep the associated ``X2GoControlSession*`` instance alive?
+        @param keep_controlsession_alive: On last :func:`X2GoSession.disconnect() <x2go.session.X2GoSession.disconnect()>` keep the associated ``X2GoControlSession*`` instance alive?
         @ŧype keep_controlsession_alive: ``bool``
         @param add_to_known_hosts: Auto-accept server host validity?
         @type add_to_known_hosts: ``bool``
@@ -1138,8 +1138,8 @@ class X2GoSession(object):
 
     def check_host(self):
         """\
-        Provide a host check mechanism. This method basically calls the L{HOOK_check_host_dialog()} method
-        which by itself calls the L{X2GoClient.HOOK_check_host_dialog()} method. Make sure you
+        Provide a host check mechanism. This method basically calls the :func:`HOOK_check_host_dialog()` method
+        which by itself calls the :func:`X2GoClient.HOOK_check_host_dialog() <x2go.client.X2GoClient.HOOK_check_host_dialog()>` method. Make sure you
         override any of these to enable user interaction on X2Go server validity checks.
 
 
@@ -1514,7 +1514,7 @@ class X2GoSession(object):
         If X2Go client-side printing is enable within this X2Go session you can use
         this method to alter the way how incoming print spool jobs are handled/processed.
 
-        For further information, please refer to the documentation of the L{X2GoClient.set_session_print_action()}
+        For further information, please refer to the documentation of the :func:`X2GoClient.set_session_print_action() <x2go.client.X2GoClient.set_session_print_action()>`
         method.
 
         :param print_action: one of the named above print actions, either as string or class instance
@@ -1851,7 +1851,7 @@ class X2GoSession(object):
             the new session (Default value = None)
         :type cmd: ``str``
         :param progress_event: a ``thread.Event`` object that notifies a status object like the one in
-            L{utils.ProgressStatus}. (Default value = None)
+            :class:`x2go.utils.ProgressStatus`. (Default value = None)
         :type progress_event: ``obj``
         :returns: returns ``True`` if resuming the session has been successful, ``False`` otherwise
         :rtype: ``bool``
@@ -1883,7 +1883,7 @@ class X2GoSession(object):
             the new session (Default value = None)
         :type cmd: ``str``
         :param progress_event: a ``thread.Event`` object that notifies a status object like the one in
-            L{utils.ProgressStatus}. (Default value = None)
+            :class:`x2go.utils.ProgressStatus`. (Default value = None)
         :type progress_event: ``obj``
         :returns: returns ``True`` if resuming the session has been successful, ``False`` otherwise
         :rtype: ``bool``
@@ -2127,7 +2127,7 @@ class X2GoSession(object):
         :param cmd: manually hand over the command that is to be launched in the new session (Default value = None)
         :type cmd: ``str``
         :param progress_event: a ``thread.Event`` object that notifies a status object like the one in
-            L{utils.ProgressStatus}. (Default value = None)
+            :class:`x2go.utils.ProgressStatus`. (Default value = None)
         :type progress_event: ``obj``
         :returns: returns ``True`` if starting the session has been successful, ``False`` otherwise
         :rtype: ``bool``
@@ -2156,7 +2156,7 @@ class X2GoSession(object):
             the server-side ``x2golistdesktops`` command might block client I/O. (Default value = True)
         :type check_desktop_list: ``bool``
         :param progress_event: a ``thread.Event`` object that notifies a status object like the one in
-            L{utils.ProgressStatus}. (Default value = None)
+            :class:`x2go.utils.ProgressStatus`. (Default value = None)
         :type progress_event: ``obj``
         :returns: returns ``True`` if starting the session has been successful, ``False`` otherwise
         :rtype: ``bool``
@@ -2195,7 +2195,7 @@ class X2GoSession(object):
             the server-side ``x2golistdesktops`` command might block client I/O. (Default value = True)
         :type check_desktop_list: ``bool``
         :param progress_event: a ``thread.Event`` object that notifies a status object like the one in
-            L{utils.ProgressStatus}. (Default value = None)
+            :class:`x2go.utils.ProgressStatus`. (Default value = None)
         :type progress_event: ``obj``
         :returns: returns ``True`` if starting the session has been successful, ``False`` otherwise
         :rtype: ``bool``
diff --git a/x2go/sftpserver.py b/x2go/sftpserver.py
index a47ad54..02997d0 100644
--- a/x2go/sftpserver.py
+++ b/x2go/sftpserver.py
@@ -288,7 +288,7 @@ class _SFTPServerInterface(paramiko.SFTPServerInterface):
         :param attr: file attributes
         :type attr: ``class``
         :returns: file handle/object for remote file, on failure: returns a Paramiko/SSH return code
-        :rtype: L{_SFTPHandle} instance or ``int``
+        :rtype: :class:`x2go.sftpserver._SFTPHandle` instance or ``int``
 
         """
         path = self._realpath(path)
@@ -538,20 +538,20 @@ class X2GoRevFwTunnelToSFTP(rforward.X2GoRevFwTunnel):
     def run(self):
         """\
         This method gets run once an :class:`x2go.sftpserver.X2GoRevFwTunnelToSFTP` has been started with its
-        L{start()} method. Use :class:`x2go.sftpserver.X2GoRevFwTunnelToSFTP`.stop_thread() to stop the
+        :func:`start()` method. Use :func:`X2GoRevFwTunnelToSFTP.stop_thread() <x2go.sftpserver.X2GoRevFwTunnelToSFTP.stop_thread()>` to stop the
         reverse forwarding tunnel again (refer also to its pause() and resume() method).
 
-        L{X2GoRevFwTunnelToSFTP.run()} waits for notifications of an appropriate incoming
-        Paramiko/SSH channel (issued by L{X2GoRevFwTunnelToSFTP.notify()}). Appropriate in
+        :func:`X2GoRevFwTunnelToSFTP.run() <x2go.rforward.X2GoRevFwTunnelToSFTP.run()>` waits for notifications of an appropriate incoming
+        Paramiko/SSH channel (issued by :func:`X2GoRevFwTunnelToSFTP.notify() <x2go.rforward.X2GoRevFwTunnelToSFTP.notify()>`). Appropriate in
         this context means, that its starting point on the X2Go server matches the class's
         property ``server_port``.
 
-        Once a new incoming channel gets announced by the L{notify()} method, a new
+        Once a new incoming channel gets announced by the :func:`notify()` method, a new
         :class:`x2go.sftpserver.X2GoRevFwSFTPChannelThread` instance will be initialized. As a data stream handler,
-        the function L{x2go_rev_forward_sftpchannel_handler()} will be used.
+        the function :func:`x2go_rev_forward_sftpchannel_handler()` will be used.
 
         The channel will last till the connection gets dropped on the X2Go server side or
-        until the tunnel gets paused by an L{X2GoRevFwTunnelToSFTP.pause()} call or
+        until the tunnel gets paused by an :func:`X2GoRevFwTunnelToSFTP.pause() <x2go.rforward.X2GoRevFwTunnelToSFTP.pause()>` call or
         stopped via the ``X2GoRevFwTunnelToSFTP.stop_thread()`` method.
 
 
@@ -596,7 +596,7 @@ def x2go_rev_forward_sftpchannel_handler(chan=None, auth_key=None, logger=None):
         - ... if the connecting application closes the connection and thus, drops
           the sFTP channel, or
         - ... if the :class:`x2go.sftpserver.X2GoRevFwTunnelToSFTP` parent thread gets paused. The call
-          of L{X2GoRevFwTunnelToSFTP.pause()} on the instance can be used to shut down all incoming
+          of :func:`X2GoRevFwTunnelToSFTP.pause() <x2go.rforward.X2GoRevFwTunnelToSFTP.pause()>` on the instance can be used to shut down all incoming
           tunneled SSH connections associated to this :class:`x2go.sftpserver.X2GoRevFwTunnelToSFTP` instance
           from within a Python X2Go application.
 
@@ -641,4 +641,4 @@ def x2go_rev_forward_sftpchannel_handler(chan=None, auth_key=None, logger=None):
 
 
 class X2GoRevFwSFTPChannelThread(rforward.X2GoRevFwChannelThread): pass
-"""A clone of L{rforward.X2GoRevFwChannelThread}."""
+"""A clone of :class:`x2go.rforward.X2GoRevFwChannelThread`."""
diff --git a/x2go/utils.py b/x2go/utils.py
index 8d19c0c..6f6e015 100644
--- a/x2go/utils.py
+++ b/x2go/utils.py
@@ -384,7 +384,7 @@ def session_names_by_timestamp(session_infos):
     """\
     Sorts session profile names by their timestamp (as used in the file format's section name).
 
-    :param session_infos: a dictionary of session infos as reported by L{X2GoClient.list_sessions()}
+    :param session_infos: a dictionary of session infos as reported by :func:`X2GoClient.list_sessions() <x2go.client.X2GoClient.list_sessions()>`
     :type session_infos: ``dict``
     :returns: a timestamp-sorted list of session names found in ``session_infos``
     :rtype: ``list``
@@ -818,7 +818,7 @@ class ProgressStatus(object):
 
     def __iter__(self):
         """\
-        Intialize the L{ProgressStatus} iterator object.
+        Intialize the :class:`x2go.utils.ProgressStatus` iterator object.
 
         """
         self.status = self.progress_func()
diff --git a/x2go/xserver.py b/x2go/xserver.py
index b4e7ce9..fa3a0e2 100644
--- a/x2go/xserver.py
+++ b/x2go/xserver.py
@@ -59,7 +59,7 @@ class X2GoClientXConfig(inifiles.X2GoIniFile):
     def __init__(self, config_files=_X2GO_XCONFIG_CONFIGFILES, defaults=_X2GO_CLIENTXCONFIG_DEFAULTS, logger=None, loglevel=log.loglevel_DEFAULT):
         """\
         Constructs an :class:`x2go.xserver.X2GoClientXConfig` instance. This is normally done by an :class:`x2go.client.X2GoClient` instance.
-        You can retrieve this :class:`x2go.xserver.X2GoClientXConfig` instance with the ``X2GoClient.get_client_xconfig()``
+        You can retrieve this :class:`x2go.xserver.X2GoClientXConfig` instance with the :func:`X2GoClient.get_client_xconfig() <x2go.client.X2GoClient.get_client_xconfig()>`
         method.
 
         On construction the :class:`x2go.xserver.X2GoClientXConfig` instance is filled with values from the configuration files::
@@ -286,7 +286,7 @@ class X2GoXServer(threading.Thread):
 
         @param xserver_name: name of the XServer to start (refer to the xconfig file for available names)
         @type xserver_name: ``str``
-        @param xserver_config: XServer configuration node (as derived from L{X2GoClientXConfig.get_xserver_config()}
+        @param xserver_config: XServer configuration node (as derived from :func:`X2GoClientXConfig.get_xserver_config() <x2go.xserver.X2GoClientXConfig.get_xserver_config()>`
         @type xserver_config: ``dict``
         @param logger: you can pass an :class:`x2go.logger.X2GoLogger` object to the :class:`x2go.xserver.X2GoClientXConfig` constructor
         @type logger: ``obj``

diff --git a/x2go/backends/control/plain.py b/x2go/backends/control/plain.py
index de56286..4ca8df3 100644
--- a/x2go/backends/control/plain.py
+++ b/x2go/backends/control/plain.py
@@ -1501,15 +1501,15 @@ class X2GoControlSession(paramiko.SSHClient):
         """\
         Start a new X2Go session.
 
-        The L{X2GoControlSession.start()} method accepts any parameter
+        The :func:`X2GoControlSession.start() <x2go.backends.control.X2GoControlSession.start()>` method accepts any parameter
         that can be passed to any of the ``X2GoTerminalSession`` backend class
         constructors.
 
         :param kwargs: parameters that get passed through to the control session's
-            L{resume()} method, only the ``session_name`` parameter will get removed
+            :func:`resume()` method, only the ``session_name`` parameter will get removed
             before pass-through
         :type kwargs: ``dict``
         :returns: return: return value of the cascaded L{resume()} method, denoting the success or failure
             of the session startup
         :rtype: ``bool``
 
@@ -1522,7 +1522,7 @@ class X2GoControlSession(paramiko.SSHClient):
         """\
         Resume a running/suspended X2Go session.
 
-        The L{X2GoControlSession.resume()} method accepts any parameter
+        The :func:`X2GoControlSession.resume() <x2go.backends.control.X2GoControlSession.resume()>` method accepts any parameter
         that can be passed to any of the ``X2GoTerminalSession*`` backend class constructors.
 
         :param session_name: the X2Go session name (Default value = None)
@@ -1832,7 +1832,7 @@ class X2GoControlSession(paramiko.SSHClient):
 
         :param session_name: X2Go name of the session to be queried
         :type session_name: ``str``
         :returns: X2Go session running? If ``<session_name>`` is not listable by the L{list_sessions()} method then ``None`` is returned
         :rtype: ``bool`` or ``None``
 
         """
@@ -1848,7 +1848,7 @@ class X2GoControlSession(paramiko.SSHClient):
 
         :param session_name: X2Go name of the session to be queried
         :type session_name: ``str``
         :returns: X2Go session suspended? If ``<session_name>`` is not listable by the L{list_sessions()} method then ``None`` is returned
         :rtype: ``bool`` or ``None``
 
         """
@@ -1501,15 +1501,15 @@ class X2GoControlSession(paramiko.SSHClient):
             before pass-through
         :type kwargs: ``dict``
-        :returns: return: return value of the cascaded L{resume()} method, denoting the success or failure
+        :returns: return: return value of the cascaded :func:`resume()` method, denoting the success or failure
             of the session startup
         :rtype: ``bool``
@@ -1832,7 +1832,7 @@ class X2GoControlSession(paramiko.SSHClient):
         :param session_name: X2Go name of the session to be queried
         :type session_name: ``str``
-        :returns: X2Go session running? If ``<session_name>`` is not listable by the L{list_sessions()} method then ``None`` is returned
+        :returns: X2Go session running? If ``<session_name>`` is not listable by the :func:`list_sessions()` method then ``None`` is returned
         :rtype: ``bool`` or ``None``
 
@@ -1848,7 +1848,7 @@ class X2GoControlSession(paramiko.SSHClient):
         :param session_name: X2Go name of the session to be queried
         :type session_name: ``str``
-        :returns: X2Go session suspended? If ``<session_name>`` is not listable by the L{list_sessions()} method then ``None`` is returned
+        :returns: X2Go session suspended? If ``<session_name>`` is not listable by the :func:`list_sessions()` method then ``None`` is returned
         :rtype: ``bool`` or ``None``
 
diff --git a/x2go/client.py b/x2go/client.py
index 98deb67..2b46866 100644
--- a/x2go/client.py
+++ b/x2go/client.py
@@ -165,7 +165,7 @@ class X2GoClient(object):
     Most methods in this class require that you have registered a session
     with a remote X2Go server (passing of session options, initialization of the
     session object etc.) and connected to it (authentication). For these two steps
-    use these methods: L{X2GoClient.register_session()} and L{X2GoClient.connect_session()}.
+    use these methods: :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` and :func:`X2GoClient.connect_session() <x2go.client.X2GoClient.connect_session()>`.
 
 
     """
@@ -890,7 +890,7 @@ class X2GoClient(object):
         Python X2Go also supports starting multiple X2Go sessions for the same
         session profile simultaneously.
 
-        This method (L{X2GoClient.register_session()}) accepts a similar set of parameters
+        This method (:func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>`) accepts a similar set of parameters
         as the :class:`x2go.session.X2GoSession` constructor itself. For a complete set of session options refer
         there.
 
@@ -1133,7 +1133,7 @@ class X2GoClient(object):
         return self.session_registry(session_uuid)
     __get_session = get_session
     with_session = __get_session
-    """Alias for L{get_session()}."""
+    """Alias for :func:`get_session()`."""
 
     def get_session_of_session_name(self, session_name, return_object=False, match_profile_name=None):
         """\
@@ -1362,8 +1362,8 @@ class X2GoClient(object):
             a private key needed for the SSH proxy host in case the sshproxy_password is already needed for
             two-factor authentication (Default value = None)
         :type sshproxy_passphrase: ``str``
-        :param add_to_known_hosts: non-Paramiko option, if ``True`` paramiko.AutoAddPolicy()
-            is used as missing-host-key-policy. If set to ``False`` L{checkhosts.X2GoInteractiveAddPolicy()}
+        :param add_to_known_hosts: non-Paramiko option, if ``True`` ``paramiko.AutoAddPolicy()``
+            is used as missing-host-key-policy. If set to ``False`` :func:`checkhosts.X2GoInteractiveAddPolicy() <x2go.checkhosts.X2GoInteractiveAddPolicy()>`
             is used (Default value = False)
         :type add_to_known_hosts: ``bool``
         :param force_password_auth: disable SSH pub/priv key authentication mechanisms
@@ -1423,7 +1423,7 @@ class X2GoClient(object):
               external command that lets the client user handle the further processing of the
               print job (PDF) file
             - B{DIALOG} (:class:`x2go.printactions.X2GoPrintActionDIALOG`): on each incoming spool job this print action
-              will call L{X2GoClient.HOOK_open_print_dialog()}
+              will call :func:`X2GoClient.HOOK_open_print_dialog() <x2go.client.X2GoClient.HOOK_open_print_dialog()>`
 
         Each of the print action classes accepts different print action arguments. For detail
         information on these print action arguments please refer to the constructor methods of
@@ -1498,12 +1498,12 @@ class X2GoClient(object):
         session window.
 
         Before calling this method you have to register your desired session
-        with L{register_session} (initialization of session parameters) and
-        connect to it with L{connect_session} (authentication).
+        with :func:`register_session()` (initialization of session parameters) and
+        connect to it with :func:`connect_session()` (authentication).
 
         :param session_uuid: the X2Go session's UUID registry hash
         :type session_uuid: ``str``
         :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.start()} method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
         :rtype: ``bool``
@@ -1542,7 +1542,7 @@ class X2GoClient(object):
         :type display: ``str``
         :param share_mode: desktop sharing mode, 0 is VIEW-ONLY, 1 is FULL-ACCESS. (Default value = 0)
         :type share_mode: ``int``
         :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.share_desktop()} method
         :type sessionopts: ``dict``
         :param check_desktop_list: check if the given desktop is available on the X2Go server; handle with care as
             the server-side ``x2golistdesktops`` command might block client I/O. (Default value = False)
@@ -1569,7 +1569,7 @@ class X2GoClient(object):
     def resume_session(self, session_uuid=None, session_name=None, match_profile_name=None, **sessionopts):
         """\
         Resume or continue a suspended / running X2Go session on a
-        remote X2Go server (as specified when L{register_session} was
+        remote X2Go server (as specified when :func:`register_session()` was
         called).
 
         :param session_uuid: the X2Go session's UUID registry hash (Default value = None)
@@ -1578,7 +1578,7 @@ class X2GoClient(object):
         :type session_name: ``str``
         :param match_profile_name: only resume a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
         :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.resume()} method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
         :rtype: ``bool``
@@ -1612,9 +1612,9 @@ class X2GoClient(object):
         empty.
 
         Alternatively, you can suspend a non-associated X2Go session:
-        To do this you simply neeed to register (with the L{register_session}
+        To do this you simply neeed to register (with the :func:`register_session()`
         method) an X2Go session on the to-be-addressed remote X2Go server and
-        connect (L{connect_session}) to it. Then call this method with
+        connect (:func:`connect_session()`) to it. Then call this method with
         the freshly obtained ``session_uuid`` and the remote X2Go session
         name (as shown e.g. in x2golistsessions output).
 
@@ -1625,7 +1625,7 @@ class X2GoClient(object):
         :type session_name: ``str``
         :param match_profile_name: only suspend a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
         :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.suspend()} method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
         :rtype: ``bool``
@@ -1664,9 +1664,9 @@ class X2GoClient(object):
         empty.
 
         Alternatively, you can terminate a non-associated X2Go session:
-        To do this you simply neeed to register (L{register_session})
+        To do this you simply neeed to register (:func:`register_session()`)
         an X2Go session on the to-be-addressed remote X2Go server and
-        connect (L{connect_session}) to it. Then call this method with
+        connect (:func:`connect_session()`) to it. Then call this method with
         the freshly obtained ``session_uuid`` and the remote X2Go session
         name (as shown in e.g. x2golistsessions output).
 
@@ -1676,7 +1676,7 @@ class X2GoClient(object):
         :type session_name: ``str``
         :param match_profile_name: only terminate a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
         :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.terminate()} method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
         :rtype: ``bool``
@@ -1713,7 +1713,7 @@ class X2GoClient(object):
         in x2goclient's »sessions« configuration file.
 
         For non-profile based session this will either be a ``profile_name`` that
-        was passed to L{register_session} or it will be the application that
+        was passed to :func:`register_session()` or it will be the application that
         instantiated this :class:`x2go.client.X2GoClient` instance.
 
         :param session_uuid: the X2Go session's UUID registry hash
@@ -2407,13 +2407,13 @@ class X2GoClient(object):
         """\
         Test if server that corresponds to the terminal session ``session_uuid`` is alive.
 
-        If the session is not connected anymore the L{X2GoClient.HOOK_on_control_session_death()} gets called.
+        If the session is not connected anymore the :func:`X2GoClient.HOOK_on_control_session_death() <x2go.client.X2GoClient.HOOK_on_control_session_death()>` gets called.
 
         :param session_uuid: the X2Go session's UUID registry hash
         :type session_uuid: ``str``
         :returns: ``True`` if X2Go server connection for :class:`x2go.session.X2GoSession` instance with <session_uuid> is alive.
         :rtype: ``bool``
         :raises X2GoControlSessionException: if the session is not connected anymore; in that case the L{HOOK_on_control_session_death} gets called.
 
         """
         try:
@@ -2556,9 +2556,9 @@ class X2GoClient(object):
         connected user on the remote X2Go server and terminate them.
 
         Before calling this method you have to setup a pro forma remote X2Go session
-        with L{X2GoClient.register_session()} (even if you do not intend to open
+        with :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` (even if you do not intend to open
         a real X2Go session window on the remote server) and connect to this session (with
-        L{X2GoClient.connect_session()}.
+        :func:`X2GoClient.connect_session() <x2go.client.X2GoClient.connect_session()>`.
 
         :param session_uuid: the X2Go session's UUID registry hash
         :type session_uuid: ``str``
@@ -2589,9 +2589,9 @@ class X2GoClient(object):
         connected X2Go server (for the authenticated user).
 
         Before calling this method you have to setup a pro forma remote X2Go session
-        with L{X2GoClient.register_session()} (even if you do not intend to open
+        with :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` (even if you do not intend to open
         a real X2Go session window on the remote server) and connect to this session (with
-        L{X2GoClient.connect_session()}.
+        :func:`X2GoClient.connect_session() <x2go.client.X2GoClient.connect_session()>`.
 
         :param session_uuid: the X2Go session's UUID registry hash (Default value = None)
         :type session_uuid: ``str``
@@ -2678,9 +2678,9 @@ class X2GoClient(object):
         for desktop sharing.
 
         Before calling this method you have to setup a pro forma remote X2Go session
-        with L{X2GoClient.register_session()} (even if you do not intend to open
+        with :func:`X2GoClient.register_session() <x2go.client.X2GoClient.register_session()>` (even if you do not intend to open
         a real X2Go session window on the remote server) and connect to this session (with
-        L{X2GoClient.connect_session()}.
+        :func:`X2GoClient.connect_session() <x2go.client.X2GoClient.connect_session()>`.
 
         :param session_uuid: the X2Go session's UUID registry hash (Default value = None)
         :type session_uuid: ``str``
@@ -2836,7 +2836,7 @@ class X2GoClient(object):
         return self.session_profiles
     __get_profiles = get_profiles
     get_session_profiles = get_profiles
-    """Alias for L{get_profiles()}."""
+    """Alias for :func:`get_profiles()`."""
 
     @property
     def profile_names(self):
@@ -1498,12 +1498,12 @@ class X2GoClient(object):
         :param session_uuid: the X2Go session's UUID registry hash
         :type session_uuid: ``str``
-        :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.start()} method
+        :param sessionopts: pass-through of options directly to the session instance's :func:`X2GoSession.start() <x2go.session.X2GoSession.start()>` method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
@@ -1542,7 +1542,7 @@ class X2GoClient(object):
         :param share_mode: desktop sharing mode, 0 is VIEW-ONLY, 1 is FULL-ACCESS. (Default value = 0)
         :type share_mode: ``int``
-        :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.share_desktop()} method
+        :param sessionopts: pass-through of options directly to the session instance's :func:`X2GoSession.share_desktop() <x2go.session.X2GoSession.share_desktop()>` method
         :type sessionopts: ``dict``
         :param check_desktop_list: check if the given desktop is available on the X2Go server; handle with care as
@@ -1578,7 +1578,7 @@ class X2GoClient(object):
         :param match_profile_name: only resume a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
-        :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.resume()} method
+        :param sessionopts: pass-through of options directly to the session instance's :func:`X2GoSession.resume() <x2go.session.X2GoSession.resume()>` method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
@@ -1625,7 +1625,7 @@ class X2GoClient(object):
         :param match_profile_name: only suspend a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
-        :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.suspend()} method
+        :param sessionopts: pass-through of options directly to the session instance's :func:`X2GoSession.suspend() <x2go.session.X2GoSession.suspend()>` method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
@@ -1676,7 +1676,7 @@ class X2GoClient(object):
         :param match_profile_name: only terminate a session if this profile name matches (Default value = None)
         :type match_profile_name: ``str``
-        :param sessionopts: pass-through of options directly to the session instance's L{X2GoSession.terminate()} method
+        :param sessionopts: pass-through of options directly to the session instance's :func:`X2GoSession.terminate() <x2go.session.X2GoSession.terminate()>` method
         :type sessionopts: ``dict``
         :returns: returns True if this method has been successful
@@ -2407,13 +2407,13 @@ class X2GoClient(object):
         :returns: ``True`` if X2Go server connection for :class:`x2go.session.X2GoSession` instance with <session_uuid> is alive.
         :rtype: ``bool``
-        :raises X2GoControlSessionException: if the session is not connected anymore; in that case the L{HOOK_on_control_session_death} gets called.
+        :raises X2GoControlSessionException: if the session is not connected anymore; in that case the :func:`HOOK_on_control_session_death()` gets called.
 
         """
--
Alioth's /home/x2go-admin/maintenancescripts/git/hooks/post-receive-email on /srv/git/code.x2go.org/python-x2go.git


More information about the x2go-commits mailing list